==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/acl.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] =
"$Id: acl.c,v 1.3 2003/11/19 17:44:20 lwa Exp $";

#include "config.h"

#include <string.h>

#include "lmtp.h"


/*
 * look in slist for
 * user@domain.example
 * @domain.example
 * @*.example
 * @
 */

char *acl_mailbox(struct slist *acl, char *key) {
  if (acl == NULL || acl->nmemb == 0) { /* shortcut */
    return NULL;
  } else {
    char *ret = slist_get_value(acl, key);
    if (ret == NULL) {
      char *domain = strchr(key, '@');
      char skey[255];
      if (domain) {
	ret = slist_get_value(acl, domain);
	if (ret== NULL) {
	  skey[0] = '@';
	  skey[1] = '*';
	  while((domain = strchr(domain, '.')) != NULL) {
	    strncpy(skey+2, domain, sizeof(skey) - 3);
	    skey[sizeof(skey) - 1] = 0;
	    if ((ret = slist_get_value(acl, skey)) != NULL)
	      return ret;
	    domain++; /* skip '.' */
	  }
	}
      }
    if (ret == NULL)
      ret = slist_get_value(acl, "@");
    }
    return ret;
  }
}

==> lmtpd-0.10.7.tar.gz: lmtpd-0.10.7/acl.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED =
"$Id: acl.c,v 1.5 2004/10/26 09:59:19 lwa Exp $";



#include <string.h>

#include "lmtp.h"


/*
 * look in slist for
 * user@domain.example
 * @domain.example
 * @*.example
 * @
 */

char *acl_mailbox(struct slist *acl, char *key) {
  if (acl == NULL || acl->nmemb == 0) { /* shortcut */
    return NULL;
  } else {
    char *ret = slist_get_value(acl, key);
    if (ret == NULL) {
      char *domain = strchr(key, '@');
      char skey[255];
      if (domain) {
	ret = slist_get_value(acl, domain);
	if (ret== NULL) {
	  skey[0] = '@';
	  skey[1] = '*';
	  while((domain = strchr(domain, '.')) != NULL) {
	    strncpy(skey+2, domain, sizeof(skey) - 3);
	    skey[sizeof(skey) - 1] = 0;
	    if ((ret = slist_get_value(acl, skey)) != NULL)
	      return ret;
	    domain++; /* skip '.' */
	  }
	}
      }
    if (ret == NULL)
      ret = slist_get_value(acl, "@");
    }
    return ret;
  }
}


char *find_relist(struct regexp_list *rl, char *key) {
  while(rl) {
    if (regexec(&rl->preg, key, 0, NULL, 0) == 0) 
      return rl->action;
    rl = rl->next;
  }
  return NULL;
}
